/**************************************************************************
 *   tip.h                                                                *
 *                                                                        *
 *   Copyright (C) 1999 Chris Allegretta                                  *
 *   This program is free software; you can redistribute it and/or modify *
 *   it under the terms of the GNU General Public License as published by *
 *   the Free Software Foundation; either version 1, or (at your option)  *
 *   any later version.                                                   *
 *                                                                        *
 *   This program is distributed in the hope that it will be useful,      *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 *   GNU General Public License for more details.                         *
 *                                                                        *
 *   You should have received a copy of the GNU General Public License    *
 *   along with this program; if not, write to the Free Software          *
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.            *
 *                                                                        *
 **************************************************************************/

#ifdef HAVE_NCURSES_H
#include <ncurses.h>
#else /* Uh oh */
#include <curses.h> 
#endif

#ifdef HAVE_MALLOC_H
#include <malloc.h>
#endif


#ifndef TIP_H
#define TIP_H 1

#define VERMSG "TIP " VERSION

/* Structure types */
typedef struct filestruct {
    char *data;
    struct filestruct *next;	/* Next node */
    struct filestruct *prev;	/* Previous node */
    long bytes;			/* # of Bytes before this line */
    long lineno;		/* The line number */
} filestruct;

typedef struct shortcut {
   int val;              /* Actual sequence that generates the keystroke */
   char desc[50];       /* Description, e.g. "Page Up" */
} shortcut;

/* Control key sequences, chaning these would be very very bad */

#define TIP_CONTROL_A 1
#define TIP_CONTROL_B 2
#define TIP_CONTROL_C 3
#define TIP_CONTROL_D 4
#define TIP_CONTROL_E 5
#define TIP_CONTROL_F 6
#define TIP_CONTROL_G 7
#define TIP_CONTROL_H 8
#define TIP_CONTROL_I 9
#define TIP_CONTROL_J 10
#define TIP_CONTROL_K 11
#define TIP_CONTROL_L 12
#define TIP_CONTROL_M 13
#define TIP_CONTROL_N 14
#define TIP_CONTROL_O 15
#define TIP_CONTROL_P 16
#define TIP_CONTROL_Q 17
#define TIP_CONTROL_R 18
#define TIP_CONTROL_S 19
#define TIP_CONTROL_T 20
#define TIP_CONTROL_U 21
#define TIP_CONTROL_V 22
#define TIP_CONTROL_W 23
#define TIP_CONTROL_X 24
#define TIP_CONTROL_Y 25
#define TIP_CONTROL_Z 26

#define TIP_ALT_A 'a'
#define TIP_ALT_B 'b'
#define TIP_ALT_C 'c'
#define TIP_ALT_D 'd'
#define TIP_ALT_E 'e'
#define TIP_ALT_F 'f'
#define TIP_ALT_G 'g'
#define TIP_ALT_H 'h'
#define TIP_ALT_I 'i'
#define TIP_ALT_J 'j'
#define TIP_ALT_K 'k'
#define TIP_ALT_L 'l'
#define TIP_ALT_M 'm'
#define TIP_ALT_N 'n'
#define TIP_ALT_O 'o'
#define TIP_ALT_P 'p'
#define TIP_ALT_Q 'q'
#define TIP_ALT_R 'r'
#define TIP_ALT_S 's'
#define TIP_ALT_T 't'
#define TIP_ALT_U 'u'
#define TIP_ALT_V 'v'
#define TIP_ALT_W 'w'
#define TIP_ALT_X 'x'
#define TIP_ALT_Y 'y'
#define TIP_ALT_Z 'z'

#define TIP_ALT_CAPITALA 'A'
#define TIP_ALT_CAPITALB 'B'
#define TIP_ALT_CAPITALC 'C'
#define TIP_ALT_CAPITALD 'D'
#define TIP_ALT_CAPITALE 'E'
#define TIP_ALT_CAPITALF 'F'
#define TIP_ALT_CAPITALG 'G'
#define TIP_ALT_CAPITALH 'H'
#define TIP_ALT_CAPITALI 'I'
#define TIP_ALT_CAPITALJ 'J'
#define TIP_ALT_CAPITALK 'K'
#define TIP_ALT_CAPITALL 'L'
#define TIP_ALT_CAPITALM 'M'
#define TIP_ALT_CAPITALN 'N'
#define TIP_ALT_CAPITALO 'O'
#define TIP_ALT_CAPITALP 'P'
#define TIP_ALT_CAPITALQ 'Q'
#define TIP_ALT_CAPITALR 'R'
#define TIP_ALT_CAPITALS 'S'
#define TIP_ALT_CAPITALT 'T'
#define TIP_ALT_CAPITALU 'U'
#define TIP_ALT_CAPITALV 'V'
#define TIP_ALT_CAPITALW 'W'
#define TIP_ALT_CAPITALX 'X'
#define TIP_ALT_CAPITALY 'Y'
#define TIP_ALT_CAPITALZ 'Z'

/* Some semi-changeable keybindings, dont play with unless you're sure you
know what you're doing */

#define TIP_INSERTFILE_KEY	TIP_CONTROL_R
#define TIP_EXIT_KEY 		TIP_CONTROL_X
#define TIP_WRITEOUT_KEY	TIP_CONTROL_O
#define TIP_GOTO_KEY		TIP_CONTROL_G
#define TIP_WHEREIS_KEY		TIP_CONTROL_W
#define TIP_REPLACE_KEY		TIP_CONTROL_P
#define TIP_PREVPAGE_KEY	TIP_CONTROL_Y
#define TIP_NEXTPAGE_KEY	TIP_CONTROL_V
#define TIP_CUT_KEY		TIP_CONTROL_K
#define TIP_UNCUT_KEY		TIP_CONTROL_U
#define TIP_CURSORPOS_KEY	TIP_CONTROL_C
#define TIP_SPELLING_KEY	TIP_CONTROL_T
#define TIP_FIRSTLINE_KEY	TIP_PREVPAGE_KEY
#define TIP_LASTLINE_KEY	TIP_NEXTPAGE_KEY
#define TIP_CANCEL_KEY		TIP_CONTROL_C
#define TIP_CASE_KEY		TIP_CONTROL_A
#define TIP_REFRESH_KEY		TIP_CONTROL_L
#define TIP_SPELL_KEY		TIP_CONTROL_T


#define MAIN_LIST_LEN 12
#define WHEREIS_LIST_LEN 4
#define REPLACE_LIST_LEN 4
#define GOTO_LIST_LEN 3
#define WRITEFILE_LIST_LEN 1

#endif                             
